import 'dart:io';
import 'dart:typed_data';
import 'package:get/get.dart' hide ContextExtensionss;
import 'package:image/image.dart' as img;
import 'package:flutter/cupertino.dart';
import 'package:step_progress_indicator/step_progress_indicator.dart';

import '../../../widgets/app_button.dart';
import '../../../configs/config.dart';
import 'id_card_scanner_view.dart';

class ViewCard extends StatefulWidget {
  const ViewCard({Key? key, required this.path}) : super(key: key);
  final String path;

  @override
  State<ViewCard> createState() => _ViewCardState();
}

class _ViewCardState extends State<ViewCard> {
  final imageKey = GlobalKey();
  Uint8List? bytes;
  @override
  Widget build(BuildContext context) {
    final size = Size(
      context.width * .8,
      (context.width * .8) / (5 / 3.5),
    );
    return Scaffold(
      backgroundColor: Colors.black,
      body: Stack(
        children: [
          Image.file(File(widget.path)).centered(),
          Align(
            alignment: Alignment.center,
            child: Container(
              width: size.width,
              height: size.height,
              key: imageKey,
              child: CustomPaint(
                size: size,
                painter: MarkerCanvas(size: size),
              ),
            ),
          ),
          if (bytes != null)
            Align(
              alignment: Alignment.topCenter,
              child: Image.memory(bytes!)
                  .box
                  .border(color: Colors.white)
                  .size(size.width, size.height)
                  .make(),
            ),
          Align(
            alignment: Alignment.bottomCenter,
            child: AppButton(
              'Crop',
              onPressed: cropImage,
            ).h(50).w(220),
          )
        ],
      ),
    );
  }

  void cropImage() async {
    var src = img.decodeImage(File(widget.path).readAsBytesSync());
    var widthRatio = src!.width / Get.width;
    var heightRatio = src.height / Get.height;
    final rect = imageKey.globalPaintBounds;
    final newRect = Rect.fromLTWH(
      (src.width - (rect.width) * widthRatio) / 2,
      (src.height - (rect.height) * heightRatio) / 2,
      (rect.width) * widthRatio,
      (rect.height) * heightRatio,
    );
    src = img.copyCrop(
      src,
      (newRect.left).floor(),
      (newRect.top).floor(),
      newRect.width.floor(),
      newRect.height.floor(),
    );
    setState(() {
      bytes = Uint8List.fromList(img.encodeJpg(src!));
    });
  }
}

extension GlobalKeyExtension on GlobalKey {
  Rect get globalPaintBounds {
    final renderObject = currentContext?.findRenderObject() as RenderBox;
    var translation = renderObject.getTransformTo(null).getTranslation();
    return renderObject.paintBounds.shift(Offset(translation.x, translation.y));
  }
}

class CircleProcess extends StatelessWidget {
  const CircleProcess({Key? key}) : super(key: key);

  @override
  Widget build(BuildContext context) {
    var math;
    return Scaffold(
      body: CircularStepProgressIndicator(
        totalSteps: 20,
        currentStep: 12,
        stepSize: 20,
        selectedColor: Colors.red,
        unselectedColor: Colors.purple[400],
        padding: math.pi / 80,
        width: 150,
        height: 150,
        startingAngle: -math.pi * 2 / 3,
        arcSize: math.pi * 2 / 3 * 2,
        gradientColor: LinearGradient(
          colors: [Colors.red, Colors.purple[400]!],
        ),
      ),
    );
  }
}
